@@ -7,6 +7,7 @@ from cytra.db.serialize_mixin import SerializeMixin
 from cytra.db.created_mixin import CreatedMixin
 from cytra.db.modified_mixin import ModifiedMixin
 from cytra.db.activation_mixin import ActivationMixin
+from cytra.db.attrstate_mixin import AttrStateMixin
 from cytra.db.filtering_mixin import FilteringMixin
 from cytra.db.ordering_mixin import OrderingMixin
 from cytra.db.pagination_mixin import PaginationMixin
@@ -26,6 +27,7 @@ __all__ = (
     CreatedMixin,
     ModifiedMixin,
     ActivationMixin,
+    AttrStateMixin,
     FilteringMixin,
     OrderingMixin,
     PaginationMixin,
